==> zwap_design_system-0.0.97.tar.gz: lib/assembled/widgets/cards/planMeeting/filter/filter.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';

/// Dynamic filter in base of the current filter type
class NetworkFilter extends StatelessWidget{

  /// The network filter type
  final NetworkFilterElement networkFilter;

  /// Current value selected for the current filter
  final String currentValue;

  /// Changing value callBack for the current filter
  final Function(String value) changeValueCallBack;

  NetworkFilter({Key? key,
    required this.networkFilter,
    required this.currentValue,
    required this.changeValueCallBack
  }): super(key: key);

  @override
  Widget build(BuildContext context) {
    TextEditingController controller = TextEditingController();
    controller.addListener(() {
      this.changeValueCallBack(controller.value.toString());
    });
    switch(this.networkFilter.filterType){
      case FilterType.inputText:
        return BaseInput(
          placeholderText: this.networkFilter.placeholder,
          inputType: InputType.inputText,
          controller: controller,
        );
      case FilterType.inputDropDown:
        return CustomDropDown(
            values: this.networkFilter.filtersOptions,
            handleChange: (String value) => this.changeValueCallBack(value)
        );
      case FilterType.buttonSide:
        List<Widget> children = [];
        this.networkFilter.filtersOptions.forEach((element) {
          children.add(
            BaseButton(
                buttonText: element,
                buttonTypeStyle: element == currentValue ? ButtonTypeStyle.pinkyButton : ButtonTypeStyle.greyButton,
                onPressedCallback: () => this.changeValueCallBack(element)
            )
          );
        });
        return Row(
          children: children,
        );
    }
  }



}

==> zwap_design_system-0.0.98.tar.gz: lib/assembled/widgets/cards/planMeeting/filter/filter.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';

/// Dynamic filter in base of the current filter type
class NetworkFilter extends StatelessWidget{

  /// The network filter type
  final NetworkFilterElement networkFilter;

  /// Current value selected for the current filter
  final String currentValue;

  /// Changing value callBack for the current filter
  final Function(String value) changeValueCallBack;

  NetworkFilter({Key? key,
    required this.networkFilter,
    required this.currentValue,
    required this.changeValueCallBack
  }): super(key: key);

  @override
  Widget build(BuildContext context) {
    TextEditingController controller = TextEditingController();
    controller.addListener(() {
      this.changeValueCallBack(controller.text);
    });
    switch(this.networkFilter.filterType){
      case FilterType.inputText:
        return BaseInput(
          placeholderText: this.networkFilter.placeholder,
          inputType: InputType.inputText,
          controller: controller,
        );
      case FilterType.inputDropDown:
        return CustomDropDown(
            values: this.networkFilter.filtersOptions,
            handleChange: (String value) => this.changeValueCallBack(value)
        );
      case FilterType.buttonSide:
        List<Widget> children = [];
        this.networkFilter.filtersOptions.forEach((element) {
          children.add(
            BaseButton(
                buttonText: element,
                buttonTypeStyle: element == currentValue ? ButtonTypeStyle.pinkyButton : ButtonTypeStyle.greyButton,
                onPressedCallback: () => this.changeValueCallBack(element)
            )
          );
        });
        return Row(
          children: children,
        );
    }
  }



}
